@@ -12,40 +12,45 @@ create.help.button <- function(topic, package, parent.group, parent.window) {
 		handler=function(h, ...) {
 			oldhtmloption <- options(htmlhelp=FALSE);
 			oldchmoption <- options(chmhelp=FALSE);
-			ghelp(topic=topic, package=package, 
-					cont=gwindow(parent=parent.window, width=700, height=700));
+			ltop <- length(topic)
+			gh <- ghelp(topic=topic[ltop], package=package, 
+					container=gwindow(parent=parent.window, width=700, height=700));
+			if(ltop > 1) {
+				for(i in (ltop-1):1) # create the pages in reverse order in order to have focus on the first one
+					add(gh, list(topic=topic[i], package=package))
+			}
 			options(htmlhelp=oldhtmloption);
 			options(chmhelp=oldchmoption)
 		})
-	gbutton(action=helpaction, cont=parent.group)
+	gbutton(action=helpaction, container=parent.group)
 }
 
-create.sim.dir.widget <- function(env, parent, main.win, type, default, dir.widget.name='sim.dir') {
-	sim.g <- ggroup(horizontal=TRUE, cont=parent)
-	glabel("Simulation directory:", cont=sim.g)
-	glabel("<span color='red'>*</span>", markup=TRUE, cont=sim.g)
-	env[[dir.widget.name]] <- gfilebrowse(default, type='selectdir', width=40, quote=FALSE, cont=sim.g)
-	create.info.button(dir.widget.name, sim.g, main.win, env, type=type)
+create.sim.dir.widget <- function(env, parent, main.win, default, dir.widget.name='sim.dir', ...) {
+	sim.g <- ggroup(horizontal=TRUE, container=parent)
+	glabel("Simulation directory:", container=sim.g)
+	glabel("<span color='red'>*</span>", markup=TRUE, container=sim.g)
+	env[[dir.widget.name]] <- gfilebrowse(default, type='selectdir', width=40, quote=FALSE, container=sim.g)
+	create.info.button(dir.widget.name, sim.g, main.win, env, ...)
 }
 
-create.info.button <- function(dir.widget.name, parent.group, parent.window, env, type) {
+create.info.button <- function(dir.widget.name, parent.group, parent.window, env, type, no.mcmc=FALSE) {
 	infoaction <- gaction(label='Info', icon='info', handler=show.summary,
 					action=list(mw=parent.window, env=env, dir.widget.name=dir.widget.name,
-								type=type))
-	gbutton(action=infoaction, cont=parent.group)
+								type=type, no.mcmc=no.mcmc))
+	gbutton(action=infoaction, container=parent.group)
 }
 
 create.graphics.window <- function(parent, title='', dpi=80, ps=10, ...) {
 	e <- new.env()
 	win <- gwindow(title, parent=parent, horizontal=FALSE)
-	g <- ggroup(cont=win, horizontal=FALSE, expand=TRUE)
-	g1 <- ggroup(cont=g, horizontal=TRUE)
-	glabel("Output type:", cont=g1)
+	g <- ggroup(container=win, horizontal=FALSE, expand=TRUE)
+	g1 <- ggroup(container=g, horizontal=TRUE)
+	glabel("Output type:", container=g1)
 	#types <- formals(savePlot)$type
-	e$type <- gdroplist(c("pdf", "postscript", "png", "jpeg", "tiff", "bmp"), cont=g1)
-	gb <- gbutton('Save', cont=g1)
-	g2 <- ggroup(cont=g, horizontal=TRUE, expand=TRUE)
-	ggraphics(cont=g2, ps=ps, dpi=dpi, ...)
+	e$type <- gdroplist(c("pdf", "postscript", "png", "jpeg", "tiff", "bmp"), container=g1)
+	gb <- gbutton('Save', container=g1)
+	g2 <- ggroup(container=g, horizontal=TRUE, expand=TRUE)
+	ggraphics(container=g2, ps=ps, dpi=dpi, ...)
 	addHandlerClicked(gb, handler=saveGraph, action=list(mw=win, env=e, dpi=dpi, dev=dev.cur()))
 	Sys.sleep(1)
 	return(g)
@@ -96,22 +101,27 @@ show.summary <- function(h, ...) {
 	type <- h$action$type
 	warn <- getOption('warn')
 	options(warn=-1) # disable warning messages
-	mcmc.set <- do.call(paste('get.', type, '.mcmc', sep=''), list(dir))
+	if(!h$action$no.mcmc) {
+		mcmc.set <- do.call(paste('get.', type, '.mcmc', sep=''), list(dir))
+	} 
 	# get prediction
 	pred <- do.call(paste('get.', type, '.prediction', sep=''), list(sim.dir=dir))
 	options(warn=warn)
 	
 	con <- textConnection("info", "w", local=TRUE)
 	sink(con)
-	if (is.null(mcmc.set)) {
-		cat('No simulation available in this directory.')
-	} else { 
-		cat('Simulation results\n')
-		cat('********************\n')
-		print(summary(mcmc.set, meta.only=TRUE))
-		cat('===============================\n')
+	if(!h$action$no.mcmc) {
+		if (is.null(mcmc.set)) {
+			cat('No simulation available in this directory.')
+		} else { 
+			cat('Simulation results\n')
+			cat('********************\n')
+			print(summary(mcmc.set, meta.only=TRUE))
+			cat('===============================\n')
+		}
 	}
-	if (!is.null(pred)) {		
+	if (is.null(pred)) {
+		cat('\nNo projections available in this directory.\n')	} else {	
 		cat('\nProjections for end year:', pred$end.year)
 		cat('\n------------------')
 		print(summary(pred))
@@ -119,7 +129,7 @@ show.summary <- function(h, ...) {
 	sink()
 	close(con)
 	info.win <- gwindow('Directory Info', parent=h$action$mw, width=500, height=400)
-	gtext(info, cont=info.win)
+	gtext(info, container=info.win)
 
 }
 
@@ -137,6 +147,8 @@ get.parameters <- function(par.names, env, quote=FALSE, retrieve.from.widgets=TR
 		if(any(par == par.names$numeric)) params[[par]] <- as.numeric(params[[par]])
 		if(any(par == par.names$numvector)) params[[par]] <- as.numeric(strsplit(params[[par]], ',')[[1]])
 		if (quote & any(par == par.names$text)) params[[par]] <- sQuote(params[[par]])
+		# convert back- to forward-slashes in path names
+		if(any(par == par.names$text)) params[[par]] <- gsub("\\\\", "/", params[[par]]) 
 		if(any(par == par.names$numtext)) {
 			warn <- getOption('warn')
 			options(warn=-1)
@@ -222,6 +234,6 @@ get.tfr.UN.data <- function(type, mcmc.set) {
 get.e0.UN.data <- function(type, mcmc.set) {
 	path <- get.data.path(type)
 	file.name <- file.path(path, paste('UN', mcmc.set$meta$wpp.year, 'e0', 
-								mcmc.set$meta$gender, '.txt', sep=''))
+								mcmc.set$meta$sex, '.txt', sep=''))
 	return(read.tfr.file(file=file.name))
 }
